package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 23, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Iter[S Bytes] struct {
}
func (it *Iter[S]) Reset(data S)
const (
Invalid Kind = iota
Null
Bool
Number
String
Opener
Object
ObjectClose
Array
ArrayClose
Comma
Colon
EOF
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.